<?php
namespace Services;

 use Zeedhi\Framework\DataSource\DataSet;
 use Zeedhi\Framework\DTO;


class ParametrosDashboardService {
    protected $connection;
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    public function getIdPadraoDash($params){
        $query = 
            "SELECT PA.NMPERFILACESSO, P.NMPAINEL
               FROM PERFACLPAINEL PP INNER JOIN PERFILACESSO PA ON PP.NRPERFILACESSO = PA.NRPERFILACESSO
                                     INNER JOIN PAINEL P ON P.NRPAINEL = PP.NRPAINEL
              WHERE IDPADRAODASH = 'S'    
                AND PP.NRPAINEL <> :P_NRPAINEL
                AND PP.CDFILIAL = :P_CDFILIAL
                AND PP.NRPERFILACESSO = :P_NRPERFILACESSO"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function updateIdpadraodash($params){
        $query = 
            "UPDATE PERFACLPAINEL
                SET IDPADRAODASH = 'N'
              WHERE IDPADRAODASH = 'S'
                AND CDFILIAL = :P_CDFILIAL
                AND NRPERFILACESSO = :P_NRPERFILACESSO"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertPerfaclpainel($params){
        $query = 
            "INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPAINEL, NRPERFILACESSO, CDFILIAL, IDPADRAODASH, NRORG)
                        VALUES (:P_NRPERFACLPAINEL, :P_NRPAINEL, :P_NRPERFILACESSO, :P_CDFILIAL, :P_IDPADRAODASH, :P_NRORG)"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function updatePerfaclpainel($params){
        $query = 
            "UPDATE PERFACLPAINEL
                SET
                    IDPADRAODASH = :P_IDPADRAODASH
              WHERE
                    NRPERFACLPAINEL = :P_NRPERFACLPAINEL AND
                    NRORG = :P_NRORG";
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function countIndicadortf($params){
        $query =
               "SELECT COUNT(1) INDICADORESTF
                  FROM INDICADORTF I
                 WHERE I.NRINDICADORTF NOT IN (SELECT NRINDICADORTF 
                                                 FROM INDICPAINEL IP
                                                WHERE NRPERFACLPAINEL = :P_NRPERFACLPAINEL)"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll()[0]["INDICADORESTF"];
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertAllIndicpainel($params){
        $query = 
            "INSERT INTO INDICPAINEL (NRINDICPAINEL, NRINDICADORTF, NRPERFACLPAINEL, IDVISUINDIC, NRORG)
                        SELECT :P_NRINDICPAINEL + ROWNUM, NRINDICADORTF, :P_NRPERFACLPAINEL, 'S', :P_NRORG
                          FROM INDICADORTF I
                         WHERE NOT EXISTS (SELECT 1 
                                            FROM INDICPAINEL IP JOIN PERFACLPAINEL P ON IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                           WHERE P.NRPAINEL = :P_NRPAINEL
                                             AND IP.NRINDICADORTF = I.NRINDICADORTF
                                             AND IP.NRPERFACLPAINEL = :P_NRPERFACLPAINEL)"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertIndicpainel($params){
        $query = 
            "INSERT INTO 
                    INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                         VALUES (:P_NRINDICPAINEL, :P_NRPERFACLPAINEL, :P_NRINDICADORTF, :P_IDVISUINDIC, :P_NRORG)"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function updateIndicpainel($params){
        $query = 
            "UPDATE INDICPAINEL
                SET
                    IDVISUINDIC = :P_IDVISUINDIC
              WHERE
                    NRINDICPAINEL = :P_NRINDICPAINEL AND
                    NRORG = :P_NRORG";
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function countIndicador($params){
        $query =
               "SELECT COUNT(*) INDICADORES
                  FROM INDICADORTF I
                 WHERE I.NRPAINEL = :P_NRPAINEL"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll()[0]["INDICADORES"];
        } catch (Exception $e){
            throw $e;
        }
    }

    public function insertExOperadorIndicador($params){
        $query = 
            "INSERT INTO 
                    INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                         VALUES (:P_NRINDICPAINEXCOPER, :P_NRINDICPAINEL, :P_CDOPERADOR, :P_NRORG)";
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    public function insertExOperadorPainel($params){
        $query = "
            INSERT INTO INDICPAINEXCOPER
              (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
              SELECT :P_NRINDICPAINEXOPER + ROWNUM, IP.NRINDICPAINEL, :P_CDOPERADOR, :P_NRORG 
                FROM INDICPAINEL IP JOIN PERFACLPAINEL P ON IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                    JOIN INDICADORTF I ON I.NRINDICADORTF = IP.NRINDICADORTF
                                                      AND P.NRPAINEL = I.NRPAINEL 
               WHERE P.NRPERFACLPAINEL = :P_NRPERFACLPAINEL
                 AND NOT EXISTS (SELECT 1 
                                   FROM INDICPAINEXCOPER IEX JOIN INDICPAINEL IPEX ON IEX.NRINDICPAINEL = IPEX.NRINDICPAINEL
                                                             JOIN PERFACLPAINEL PEX ON PEX.NRPERFACLPAINEL = IPEX.NRPERFACLPAINEL
                                  WHERE PEX.NRPAINEL = P.NRPAINEL 
                                    AND PEX.NRPERFILACESSO = P.NRPERFILACESSO
                                    AND IEX.CDOPERADOR = :P_CDOPERADOR
                                    AND PEX.CDFILIAL = :P_CDFILIAL
                                    AND I.NRINDICADORTF = IPEX.NRINDICADORTF)"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteExOperadorPainel($params, $cdoperador){
        
        $in = '(' . implode(',', $cdoperador) .')';
        $query = "
            DELETE
              FROM INDICPAINEXCOPER I
             WHERE I.NRINDICPAINEXCOPER IN (
                SELECT IEX.NRINDICPAINEXCOPER
                  FROM INDICPAINEXCOPER IEX JOIN INDICPAINEL IP ON IEX.NRINDICPAINEL = IP.NRINDICPAINEL
                                         JOIN PERFACLPAINEL P ON P.NRPERFACLPAINEL = IP.NRPERFACLPAINEL
                 WHERE P.NRPAINEL = :P_NRPAINEL
                   AND P.CDFILIAL = :P_CDFILIAL
                   AND P.NRPERFILACESSO = :P_NRPERFILACESSO
                   AND IEX.CDOPERADOR IN " . $in. ")"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function updatePadrao($params){
        $query = 
            "UPDATE PARAMFILIAL
                SET IDUTLDSBTPADRAO = :P_IDUTLDSBTPADRAO
              WHERE CDFILIAL = :P_CDFILIAL
                AND NRORG = :P_NRORG"
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteParametrizacaoUnidades($params){
        $query = "
            DELETE
              FROM PERFACLPAINEL P
             WHERE EXISTS (SELECT 1
                             FROM LISTA L
                            WHERE L.CDLISTA = P.CDFILIAL
                              AND L.NRLISTA = :P_NRLISTA
                              AND L.NRORG = :P_NRORG)
                AND P.NRORG = :P_NRORG
                AND P.NRPAINEL = NVL(:P_NRPAINEL, P.NRPAINEL)
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insereReplicar($params){
        $query = "
            DECLARE V_SEQPERFACLPAINEL NUMBER;
                    V_SEQINDICPAINEL   NUMBER;
                    V_SEQINDICPAINEXCOPER NUMBER;
                    V_COMMIT           NUMBER;
                    V_QUANT            NUMBER;
            BEGIN
               V_COMMIT := 0;
               V_QUANT := 0;
               
               FOR C_LISTA IN (SELECT L.CDLISTA
                                 FROM LISTA L
                                WHERE NRLISTA = :P_NRLISTA
                                  AND 'T' <> :P_NRLISTA
                                UNION ALL
                               SELECT F.CDFILIAL
                                 FROM FILIAL F
                                WHERE 'T' = :P_NRLISTA
                                  AND F.CDFILIAL <> :P_CDFILIAL
                                  AND NVL(F.IDCNTRRESC,'N') = 'N') LOOP
                                
                 UPDATE PARAMFILIAL
                    SET IDUTLDSBTPADRAO = (SELECT P.IDUTLDSBTPADRAO
                                             FROM PARAMFILIAL P
                                            WHERE P.CDFILIAL = :P_CDFILIAL)
                  WHERE CDFILIAL = C_LISTA.CDLISTA;
                
                  SELECT COUNT(1)
                    INTO V_QUANT
                    FROM PERFACLPAINEL P
                   WHERE P.CDFILIAL = :P_CDFILIAL
                     AND P.NRORG = :P_NRORG;
                  
                  NOVO_CODIGO('PERFACLPAINEL',V_SEQPERFACLPAINEL, V_QUANT);
                  
                  INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH, NRORG)
                       SELECT V_SEQPERFACLPAINEL+ROWNUM-1, P.NRPERFILACESSO, P.NRPAINEL, C_LISTA.CDLISTA, P.IDPADRAODASH, P.NRORG
                         FROM PERFACLPAINEL P
                        WHERE P.CDFILIAL = :P_CDFILIAL
                          AND P.NRORG = :P_NRORG;
                          
                  FOR C_PERFACLPAINEL IN (SELECT P.NRPERFACLPAINEL, O.NRPERFACLPAINEL NRORIGEM
                                            FROM PERFACLPAINEL P, PERFACLPAINEL O
                                           WHERE P.CDFILIAL = C_LISTA.CDLISTA
                                             AND P.NRORG = :P_NRORG
                                             AND P.NRPERFILACESSO = O.NRPERFILACESSO
                                             AND P.NRPAINEL = O.NRPAINEL
                                             AND O.CDFILIAL = :P_CDFILIAL) LOOP
                      SELECT COUNT(1)
                        INTO V_QUANT
                        FROM PERFACLPAINEL P, INDICPAINEL IP
                       WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                         AND IP.NRPERFACLPAINEL = C_PERFACLPAINEL.NRORIGEM
                         AND P.CDFILIAL = :P_CDFILIAL
                         AND P.NRORG = :P_NRORG;
                      
                      NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL, V_QUANT);
                       
                      INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                           SELECT V_SEQINDICPAINEL+ROWNUM-1, C_PERFACLPAINEL.NRPERFACLPAINEL, IP.NRINDICADORTF, IP.IDVISUINDIC, IP.NRORG
                             FROM PERFACLPAINEL P, INDICPAINEL IP
                            WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                              AND IP.NRPERFACLPAINEL = C_PERFACLPAINEL.NRORIGEM
                              AND P.CDFILIAL = :P_CDFILIAL
                              AND P.NRORG = :P_NRORG;
                      
                      FOR C_INDICPAINEL IN (SELECT IP.NRINDICPAINEL, IO.NRINDICPAINEL NRORIGEM
                                              FROM PERFACLPAINEL P, INDICPAINEL IP, PERFACLPAINEL O, INDICPAINEL IO
                                             WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                               AND P.CDFILIAL = C_LISTA.CDLISTA
                                               AND P.NRORG = :P_NRORG
                                               AND IO.NRPERFACLPAINEL = O.NRPERFACLPAINEL
                                               AND O.CDFILIAL = :P_CDFILIAL
                                               --AND IP.NRPERFACLPAINEL = IO.NRPERFACLPAINEL
                                               AND IP.NRINDICADORTF = IO.NRINDICADORTF) LOOP
                          SELECT COUNT(1)
                            INTO V_QUANT
                            FROM PERFACLPAINEL P, INDICPAINEL IP, INDICPAINEXCOPER EX, FILIOPER FO
                           WHERE /* EX.NRINDICPAINEL = IP.NRINDICPAINEL
                             AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                             AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                             AND P.CDFILIAL = :P_CDFILIAL
                             AND P.NRORG = :P_NRORG; */
                             EX.NRINDICPAINEL = IP.NRINDICPAINEL
                                  AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                                  AND FO.CDFILIAL = C_LISTA.CDLISTA
                                  AND FO.CDOPERADOR = EX.CDOPERADOR
                                  AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                  AND P.CDFILIAL = :P_CDFILIAL
                                  AND P.NRORG = :P_NRORG;
                          
                          NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                          
                          INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                               SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, C_INDICPAINEL.NRINDICPAINEL, EX.CDOPERADOR, EX.NRORG
                                 FROM PERFACLPAINEL P, INDICPAINEL IP, INDICPAINEXCOPER EX, FILIOPER FO
                                WHERE EX.NRINDICPAINEL = IP.NRINDICPAINEL
                                  AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                                  AND FO.CDFILIAL = C_LISTA.CDLISTA
                                  AND FO.CDOPERADOR = EX.CDOPERADOR
                                  AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                  AND P.CDFILIAL = :P_CDFILIAL
                                  AND P.NRORG = :P_NRORG;  
                      END LOOP;
                  END LOOP;
                 COMMIT;
               END LOOP;
            END;
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    public function insereCadastrar($params){
        // P_NRLISTA_UNIDADE *
        // P_UTILIZA_PADRAO *
        // P_PAINEL *
        // P_NRLISTA_PERFIL *
        // P_INDICADOR_VISIVEL *
        // P_NRLISTA_EXCECAO *
        // P_NRORG *
        $query = "DECLARE V_QUANT               NUMBER;
                    V_COMMIT              NUMBER;
                    V_SEQPERFACLPAINEL    NUMBER;
                    V_SEQINDICPAINEL      NUMBER;
                    V_SEQINDICPAINEXCOPER NUMBER;
                    V_CDFILIAL            VARCHAR2(04);
            BEGIN
               V_QUANT := 0;
               V_COMMIT := 0;
               V_CDFILIAL := ' ';
               
               IF :P_UTILIZA_PADRAO = 'S' THEN
                  FOR C_LISTA IN (SELECT FF.CDFILIAL
                                    FROM FILIAL FF
                                   WHERE EXISTS (SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :P_NRLISTA_UNIDADE
                                                    AND F.CDLISTA = FF.CDFILIAL
                                                  UNION
                                                 SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :P_NRLISTA_UNIDADE
                                                    AND F.CDLISTA = 'T')) LOOP

                     UPDATE PARAMFILIAL
                        SET IDUTLDSBTPADRAO = :P_UTILIZA_PADRAO
                      WHERE CDFILIAL = C_LISTA.CDFILIAL;
                      
                     COMMIT;
                  END LOOP;
               ELSE
                  FOR C_LISTA IN (SELECT FF.CDFILIAL, P.CDLISTA NRPERFILACESSO
                                    FROM FILIAL FF, LISTA P
                                   WHERE EXISTS (SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :P_NRLISTA_UNIDADE
                                                    AND F.CDLISTA = FF.CDFILIAL
                                                  UNION
                                                 SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :P_NRLISTA_UNIDADE
                                                    AND F.CDLISTA = 'T')
                                     AND P.NRLISTA = :P_NRLISTA_PERFIL
                                   UNION 
                                  SELECT 'P' CDFILIAL, P.CDLISTA NRPERFILACESSO
                                    FROM LISTA F, LISTA P
                                   WHERE F.NRLISTA = :P_NRLISTA_UNIDADE
                                     AND F.CDLISTA = 'P'
                                     AND P.NRLISTA = :P_NRLISTA_PERFIL
                                   ORDER BY CDFILIAL) LOOP
                      V_SEQINDICPAINEL := 0;
                      
                      IF V_CDFILIAL <> C_LISTA.CDFILIAL AND C_LISTA.CDFILIAL <> 'P' THEN
                         UPDATE PARAMFILIAL
                            SET IDUTLDSBTPADRAO = :P_UTILIZA_PADRAO
                          WHERE CDFILIAL = C_LISTA.CDFILIAL;
                          
                         V_CDFILIAL := C_LISTA.CDFILIAL;
                      END IF;
                      
                      NOVO_CODIGO('PERFACLPAINEL',V_SEQPERFACLPAINEL);
                      
                      INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH, NRORG)
                           VALUES (V_SEQPERFACLPAINEL, C_LISTA.NRPERFILACESSO, :P_PAINEL, C_LISTA.CDFILIAL, 'N', :P_NRORG);
                      
                      /* Grava nao visiveis */  
                      FOR C_INDICPAINEL IN (SELECT V_SEQPERFACLPAINEL NRPERFACLPAINEL, I.NRINDICADORTF
                                              FROM INDICADORTF I
                                             WHERE I.NRPAINEL = :P_PAINEL
                                               AND I.NRORG = :P_NRORG
                                               AND NOT INSTR(:P_INDICADOR_VISIVEL, '_'||I.NRINDICADORTF||'_') > 0) LOOP
                                               
                                        
                        NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL);
                               
                          INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                               VALUES (V_SEQINDICPAINEL, C_INDICPAINEL.NRPERFACLPAINEL, C_INDICPAINEL.NRINDICADORTF, 'N', :P_NRORG);
                        
                          IF :P_NRLISTA_EXCECAO IS NOT NULL THEN
                              SELECT COUNT(1)
                                INTO V_QUANT
                                FROM LISTA  L
                               WHERE L.NRLISTA = :P_NRLISTA_EXCECAO
                                 AND L.NRORG = :P_NRORG;
                                      
                              IF V_QUANT > 0 THEN
                                  NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                                          
                                  INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                                       SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, V_SEQINDICPAINEL, L.CDLISTA, :P_NRORG
                                         FROM LISTA  L
                                        WHERE L.NRLISTA = :P_NRLISTA_EXCECAO
                                          AND L.NRORG = :P_NRORG;
                              END IF;
                          END IF;
                      END LOOP;
                      /*  */
                      IF :P_NRLISTA_EXCECAO IS NOT NULL THEN
                          FOR C_INDICPAINEL IN (SELECT V_SEQPERFACLPAINEL NRPERFACLPAINEL, I.NRINDICADORTF
                                                  FROM INDICADORTF I
                                                 WHERE I.NRPAINEL = :P_PAINEL
                                                   AND I.NRORG = :P_NRORG
                                                   AND INSTR(:P_INDICADOR_VISIVEL, '_'||I.NRINDICADORTF||'_') > 0) LOOP
                          
                              NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL);
                                   
                              INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                                   VALUES (V_SEQINDICPAINEL, C_INDICPAINEL.NRPERFACLPAINEL, C_INDICPAINEL.NRINDICADORTF, 'S', :P_NRORG);
                            
                              IF :P_NRLISTA_EXCECAO IS NOT NULL THEN
                                  SELECT COUNT(1)
                                    INTO V_QUANT
                                    FROM LISTA  L
                                   WHERE L.NRLISTA = :P_NRLISTA_EXCECAO
                                     AND L.NRORG = :P_NRORG;
                                          
                                  IF V_QUANT > 0 THEN
                                      NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                                              
                                      INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                                           SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, V_SEQINDICPAINEL, L.CDLISTA, :P_NRORG
                                             FROM LISTA  L
                                            WHERE L.NRLISTA = :P_NRLISTA_EXCECAO
                                              AND L.NRORG = :P_NRORG;
                                  END IF;
                              END IF;
                          END LOOP;
                      END IF;
                      COMMIT;
                  END LOOP;
               END IF;
            END;
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    public function getQuantidadeNovoCodigo($params){
        $retorno = array();
        $query_perfil = "
            SELECT COUNT(1) PERFIL
               FROM PERFACLPAINEL I
             WHERE I.CDFILIAL = :P_CDFILIAL
               AND I.NRORG = :P_NRORG
            "
        ;
        $query_indicador = "
            SELECT COUNT(1) INDICADOR
              FROM INDICPAINEL I, PERFACLPAINEL P
             WHERE I.NRPERFACLPAINEL = P.NRPERFACLPAINEL
               AND P.CDFILIAL = :P_CDFILIAL
               AND P.NRORG = :P_NRORG
            "
        ;
        $query_excecao = "
            SELECT COUNT(1) EXCECAO
              FROM INDICPAINEXCOPER EX, INDICPAINEL I, PERFACLPAINEL P
             WHERE EX.NRINDICPAINEL = I.NRINDICPAINEL
               AND I.NRPERFACLPAINEL = P.NRPERFACLPAINEL
               AND P.CDFILIAL = :P_CDFILIAL
               AND P.NRORG = :P_NRORG
            "
        ;
       try {
            $std_perfil = $this->connection->prepare($query_perfil);
            $std_perfil->execute($params);
            $counPerfil = $std_perfil->fetchAll();
            $retorno['PERFIL'] = $counPerfil[0]['PERFIL'];
            
            $std_indicador = $this->connection->prepare($query_indicador);
            $std_indicador->execute($params);
            $counIndicador = $std_indicador->fetchAll();
            $retorno['INDICADOR'] = $counIndicador[0]['INDICADOR'];
            
            $std_excecao = $this->connection->prepare($query_excecao);
            $std_excecao->execute($params);
            $counExcecao = $std_excecao->fetchAll();
            $retorno['EXCECAO'] = $counExcecao[0]['EXCECAO'];
            
            return $retorno;
            
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function inserePerfilReplicar($params){
        $query = "
            INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH, NRORG)
                SELECT :P_NRPERFACLPAINEL+ROWNUM-1, P.NRPERFILACESSO, P.NRPAINEL, L.CDLISTA, P.IDPADRAODASH, P.NRORG
                  FROM PERFACLPAINEL P, LISTA L
                 WHERE P.CDFILIAL = :P_CDFILIAL
                   AND P.NRORG = :P_NRORG
                   AND L.NRLISTA = :P_NRLISTA
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insereIndicadorReplicar($params){
        $query = "
            INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                SELECT :P_NRINDICPAINEL+ROWNUM-1, IP.NRPERFACLPAINEL, IP.NRINDICADORTF, IP.IDVISUINDIC, IP.NRORG
                  FROM PERFACLPAINEL P, LISTA L, INDICPAINEL IP
                 WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                   AND P.CDFILIAL = :P_CDFILIAL
                   AND P.NRORG = :P_NRORG
                   AND L.NRLISTA = :P_NRLISTA
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insereExcecaoReplicar($params){
        $query = "
            INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                SELECT :P_INDICPAINEXCOPER+ROWNUM-1, EX.NRINDICPAINEL, EX.CDOPERADOR, EX.NRORG
                  FROM PERFACLPAINEL P, LISTA L, INDICPAINEL IP, INDICPAINEXCOPER EX
                 WHERE EX.NRINDICPAINEL = IP.NRINDICPAINEL
                   AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                   AND P.CDFILIAL = :P_CDFILIAL
                   AND P.NRORG = :P_NRORG
                   AND L.NRLISTA = :P_NRLISTA
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteTodasUnidades($params){
        $query = "
            DELETE
              FROM PERFACLPAINEL
             WHERE CDFILIAL <> :P_CDFILIAL
               AND NRORG = :P_NRORG
               AND NRPAINEL = NVL(:P_NRPAINEL, NRPAINEL)
            "
        ;
       try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    //insere lista no banco
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    //apaga lista do banco
    public function deleteLista($nrlista) {
        $params = array(
            "NRLISTA" => $nrlista
        );
        
        $sql = "DELETE FROM LISTA WHERE NRLISTA =:NRLISTA";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    //apaga lista de valores recebendo string como parametro
    public function apagarListaValores($valores){
        try{
            if(substr($valores, 0,9) == "_NRLISTA="){
                $nrlista = substr($valores, 9);
                $this->deleteLista($nrlista);
            }
        } catch(\Exception $e){
            throw $e;
        }
    }

    
}